# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpamIpamPoolsResult',
    'AwaitableGetIpamIpamPoolsResult',
    'get_ipam_ipam_pools',
    'get_ipam_ipam_pools_output',
]

@pulumi.output_type
class GetIpamIpamPoolsResult:
    """
    A collection of values returned by getIpamIpamPools.
    """
    def __init__(__self__, id=None, ids=None, ipam_pool_id=None, ipam_pool_name=None, ipam_scope_id=None, name_regex=None, names=None, output_file=None, pool_region_id=None, pools=None, resource_group_id=None, source_ipam_pool_id=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if ipam_pool_id and not isinstance(ipam_pool_id, str):
            raise TypeError("Expected argument 'ipam_pool_id' to be a str")
        pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)
        if ipam_pool_name and not isinstance(ipam_pool_name, str):
            raise TypeError("Expected argument 'ipam_pool_name' to be a str")
        pulumi.set(__self__, "ipam_pool_name", ipam_pool_name)
        if ipam_scope_id and not isinstance(ipam_scope_id, str):
            raise TypeError("Expected argument 'ipam_scope_id' to be a str")
        pulumi.set(__self__, "ipam_scope_id", ipam_scope_id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if pool_region_id and not isinstance(pool_region_id, str):
            raise TypeError("Expected argument 'pool_region_id' to be a str")
        pulumi.set(__self__, "pool_region_id", pool_region_id)
        if pools and not isinstance(pools, list):
            raise TypeError("Expected argument 'pools' to be a list")
        pulumi.set(__self__, "pools", pools)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if source_ipam_pool_id and not isinstance(source_ipam_pool_id, str):
            raise TypeError("Expected argument 'source_ipam_pool_id' to be a str")
        pulumi.set(__self__, "source_ipam_pool_id", source_ipam_pool_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Ipam Pool IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> Optional[builtins.str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "ipam_pool_id")

    @property
    @pulumi.getter(name="ipamPoolName")
    def ipam_pool_name(self) -> Optional[builtins.str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "ipam_pool_name")

    @property
    @pulumi.getter(name="ipamScopeId")
    def ipam_scope_id(self) -> Optional[builtins.str]:
        """
        Ipam scope id.
        """
        return pulumi.get(self, "ipam_scope_id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Ipam Pools.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="poolRegionId")
    def pool_region_id(self) -> Optional[builtins.str]:
        """
        The effective region of the IPAM address pool.
        """
        return pulumi.get(self, "pool_region_id")

    @property
    @pulumi.getter
    def pools(self) -> Sequence['outputs.GetIpamIpamPoolsPoolResult']:
        """
        A list of Ipam Pool Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "pools")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="sourceIpamPoolId")
    def source_ipam_pool_id(self) -> Optional[builtins.str]:
        """
        The instance ID of the source IPAM address pool.> If this parameter is not entered, the created address pool is the parent address pool.
        """
        return pulumi.get(self, "source_ipam_pool_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        The tag of the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetIpamIpamPoolsResult(GetIpamIpamPoolsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpamIpamPoolsResult(
            id=self.id,
            ids=self.ids,
            ipam_pool_id=self.ipam_pool_id,
            ipam_pool_name=self.ipam_pool_name,
            ipam_scope_id=self.ipam_scope_id,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            pool_region_id=self.pool_region_id,
            pools=self.pools,
            resource_group_id=self.resource_group_id,
            source_ipam_pool_id=self.source_ipam_pool_id,
            tags=self.tags)


def get_ipam_ipam_pools(ids: Optional[Sequence[builtins.str]] = None,
                        ipam_pool_id: Optional[builtins.str] = None,
                        ipam_pool_name: Optional[builtins.str] = None,
                        ipam_scope_id: Optional[builtins.str] = None,
                        name_regex: Optional[builtins.str] = None,
                        output_file: Optional[builtins.str] = None,
                        pool_region_id: Optional[builtins.str] = None,
                        resource_group_id: Optional[builtins.str] = None,
                        source_ipam_pool_id: Optional[builtins.str] = None,
                        tags: Optional[Mapping[str, builtins.str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpamIpamPoolsResult:
    """
    This data source provides Vpc Ipam Ipam Pool available to the user.[What is Ipam Pool](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamPool)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.get_resource_groups()
    default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
    parent_ipam_pool = alicloud.vpc.IpamIpamPool("parentIpamPool",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id="cn-hangzhou")
    default_ipam_ipam_pool = alicloud.vpc.IpamIpamPool("default",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id=parent_ipam_pool.pool_region_id,
        ipam_pool_name=name,
        source_ipam_pool_id=parent_ipam_pool.id,
        ip_version="IPv4",
        ipam_pool_description=name)
    default_get_ipam_ipam_pools = alicloud.vpc.get_ipam_ipam_pools(name_regex=default_ipam_ipam_pool.name)
    pulumi.export("alicloudVpcIpamIpamPoolExampleId", default_get_ipam_ipam_pools.pools[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Ipam Pool IDs.
    :param builtins.str ipam_pool_id: The first ID of the resource.
    :param builtins.str ipam_pool_name: The name of the resource.
    :param builtins.str ipam_scope_id: Ipam scope id.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str pool_region_id: The effective region of the IPAM address pool.
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str source_ipam_pool_id: The instance ID of the source IPAM address pool.> If this parameter is not entered, the created address pool is the parent address pool.
    :param Mapping[str, builtins.str] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipamPoolId'] = ipam_pool_id
    __args__['ipamPoolName'] = ipam_pool_name
    __args__['ipamScopeId'] = ipam_scope_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['poolRegionId'] = pool_region_id
    __args__['resourceGroupId'] = resource_group_id
    __args__['sourceIpamPoolId'] = source_ipam_pool_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getIpamIpamPools:getIpamIpamPools', __args__, opts=opts, typ=GetIpamIpamPoolsResult).value

    return AwaitableGetIpamIpamPoolsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        ipam_pool_id=pulumi.get(__ret__, 'ipam_pool_id'),
        ipam_pool_name=pulumi.get(__ret__, 'ipam_pool_name'),
        ipam_scope_id=pulumi.get(__ret__, 'ipam_scope_id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        pool_region_id=pulumi.get(__ret__, 'pool_region_id'),
        pools=pulumi.get(__ret__, 'pools'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        source_ipam_pool_id=pulumi.get(__ret__, 'source_ipam_pool_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_ipam_ipam_pools_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                               ipam_pool_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               ipam_pool_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               ipam_scope_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               pool_region_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               source_ipam_pool_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpamIpamPoolsResult]:
    """
    This data source provides Vpc Ipam Ipam Pool available to the user.[What is Ipam Pool](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamPool)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.resourcemanager.get_resource_groups()
    default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
    parent_ipam_pool = alicloud.vpc.IpamIpamPool("parentIpamPool",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id="cn-hangzhou")
    default_ipam_ipam_pool = alicloud.vpc.IpamIpamPool("default",
        ipam_scope_id=default_ipam.private_default_scope_id,
        pool_region_id=parent_ipam_pool.pool_region_id,
        ipam_pool_name=name,
        source_ipam_pool_id=parent_ipam_pool.id,
        ip_version="IPv4",
        ipam_pool_description=name)
    default_get_ipam_ipam_pools = alicloud.vpc.get_ipam_ipam_pools(name_regex=default_ipam_ipam_pool.name)
    pulumi.export("alicloudVpcIpamIpamPoolExampleId", default_get_ipam_ipam_pools.pools[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Ipam Pool IDs.
    :param builtins.str ipam_pool_id: The first ID of the resource.
    :param builtins.str ipam_pool_name: The name of the resource.
    :param builtins.str ipam_scope_id: Ipam scope id.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str pool_region_id: The effective region of the IPAM address pool.
    :param builtins.str resource_group_id: The ID of the resource group.
    :param builtins.str source_ipam_pool_id: The instance ID of the source IPAM address pool.> If this parameter is not entered, the created address pool is the parent address pool.
    :param Mapping[str, builtins.str] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['ipamPoolId'] = ipam_pool_id
    __args__['ipamPoolName'] = ipam_pool_name
    __args__['ipamScopeId'] = ipam_scope_id
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['poolRegionId'] = pool_region_id
    __args__['resourceGroupId'] = resource_group_id
    __args__['sourceIpamPoolId'] = source_ipam_pool_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getIpamIpamPools:getIpamIpamPools', __args__, opts=opts, typ=GetIpamIpamPoolsResult)
    return __ret__.apply(lambda __response__: GetIpamIpamPoolsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        ipam_pool_id=pulumi.get(__response__, 'ipam_pool_id'),
        ipam_pool_name=pulumi.get(__response__, 'ipam_pool_name'),
        ipam_scope_id=pulumi.get(__response__, 'ipam_scope_id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        pool_region_id=pulumi.get(__response__, 'pool_region_id'),
        pools=pulumi.get(__response__, 'pools'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        source_ipam_pool_id=pulumi.get(__response__, 'source_ipam_pool_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AppTemplateConfigList',
    'GetAppTemplatesTemplateResult',
    'GetAppTemplatesTemplateConfigListResult',
]

@pulumi.output_type
class AppTemplateConfigList(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: Configuration item key. Valid values: ["config.appCallbackAuthKey","config.appCallbackUrl","config.callbackClass.live","config.callbackClass.user","config.livePullDomain","config.livePushDomain","config.multipleClientsLogin","config.regionId","config.streamChangeCallbackUrl"].
        :param builtins.str value: Configuration item content.
               
               > **NOTE:**  By default, the attribute `config_list` will return all of nine keys with empty value. If you want to set one or more of the key's value, you had better also set other keys, otherwise, there will be a diff.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        Configuration item key. Valid values: ["config.appCallbackAuthKey","config.appCallbackUrl","config.callbackClass.live","config.callbackClass.user","config.livePullDomain","config.livePushDomain","config.multipleClientsLogin","config.regionId","config.streamChangeCallbackUrl"].
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        Configuration item content.

        > **NOTE:**  By default, the attribute `config_list` will return all of nine keys with empty value. If you want to set one or more of the key's value, you had better also set other keys, otherwise, there will be a diff.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAppTemplatesTemplateResult(dict):
    def __init__(__self__, *,
                 app_template_creator: builtins.str,
                 app_template_id: builtins.str,
                 app_template_name: builtins.str,
                 component_lists: Sequence[builtins.str],
                 config_lists: Sequence['outputs.GetAppTemplatesTemplateConfigListResult'],
                 create_time: builtins.str,
                 id: builtins.str,
                 integration_mode: builtins.str,
                 scene: builtins.str,
                 sdk_info: builtins.str,
                 standard_room_info: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str app_template_creator: Apply template creator.
        :param builtins.str app_template_id: The first ID of the resource.
        :param builtins.str app_template_name: The name of the resource.
        :param Sequence[builtins.str] component_lists: List of components.
        :param Sequence['GetAppTemplatesTemplateConfigListArgs'] config_lists: List of config.
        :param builtins.str create_time: Creation time.
        :param builtins.str id: The ID of the App Template.
        :param builtins.str integration_mode: Integration mode (Integrated SDK:paasSDK, Model Room: standardRoom).
        :param builtins.str scene: Application Template scenario, e-commerce business, classroom classroom.
        :param builtins.str sdk_info: SDK information.
        :param builtins.str standard_room_info: Model room information.
        :param builtins.str status: Application template usage status.
        """
        pulumi.set(__self__, "app_template_creator", app_template_creator)
        pulumi.set(__self__, "app_template_id", app_template_id)
        pulumi.set(__self__, "app_template_name", app_template_name)
        pulumi.set(__self__, "component_lists", component_lists)
        pulumi.set(__self__, "config_lists", config_lists)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "integration_mode", integration_mode)
        pulumi.set(__self__, "scene", scene)
        pulumi.set(__self__, "sdk_info", sdk_info)
        pulumi.set(__self__, "standard_room_info", standard_room_info)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="appTemplateCreator")
    def app_template_creator(self) -> builtins.str:
        """
        Apply template creator.
        """
        return pulumi.get(self, "app_template_creator")

    @property
    @pulumi.getter(name="appTemplateId")
    def app_template_id(self) -> builtins.str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "app_template_id")

    @property
    @pulumi.getter(name="appTemplateName")
    def app_template_name(self) -> builtins.str:
        """
        The name of the resource.
        """
        return pulumi.get(self, "app_template_name")

    @property
    @pulumi.getter(name="componentLists")
    def component_lists(self) -> Sequence[builtins.str]:
        """
        List of components.
        """
        return pulumi.get(self, "component_lists")

    @property
    @pulumi.getter(name="configLists")
    def config_lists(self) -> Sequence['outputs.GetAppTemplatesTemplateConfigListResult']:
        """
        List of config.
        """
        return pulumi.get(self, "config_lists")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the App Template.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="integrationMode")
    def integration_mode(self) -> builtins.str:
        """
        Integration mode (Integrated SDK:paasSDK, Model Room: standardRoom).
        """
        return pulumi.get(self, "integration_mode")

    @property
    @pulumi.getter
    def scene(self) -> builtins.str:
        """
        Application Template scenario, e-commerce business, classroom classroom.
        """
        return pulumi.get(self, "scene")

    @property
    @pulumi.getter(name="sdkInfo")
    def sdk_info(self) -> builtins.str:
        """
        SDK information.
        """
        return pulumi.get(self, "sdk_info")

    @property
    @pulumi.getter(name="standardRoomInfo")
    def standard_room_info(self) -> builtins.str:
        """
        Model room information.
        """
        return pulumi.get(self, "standard_room_info")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Application template usage status.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAppTemplatesTemplateConfigListResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: Config key.
        :param builtins.str value: Config Value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        Config key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Config Value.
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetV3TriggersResult',
    'AwaitableGetV3TriggersResult',
    'get_v3_triggers',
    'get_v3_triggers_output',
]

@pulumi.output_type
class GetV3TriggersResult:
    """
    A collection of values returned by getV3Triggers.
    """
    def __init__(__self__, function_name=None, id=None, ids=None, name_regex=None, names=None, output_file=None, triggers=None):
        if function_name and not isinstance(function_name, str):
            raise TypeError("Expected argument 'function_name' to be a str")
        pulumi.set(__self__, "function_name", function_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if triggers and not isinstance(triggers, list):
            raise TypeError("Expected argument 'triggers' to be a list")
        pulumi.set(__self__, "triggers", triggers)

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> builtins.str:
        return pulumi.get(self, "function_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Trigger IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of name of Triggers.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def triggers(self) -> Sequence['outputs.GetV3TriggersTriggerResult']:
        """
        A list of Trigger Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "triggers")


class AwaitableGetV3TriggersResult(GetV3TriggersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetV3TriggersResult(
            function_name=self.function_name,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            triggers=self.triggers)


def get_v3_triggers(function_name: Optional[builtins.str] = None,
                    ids: Optional[Sequence[builtins.str]] = None,
                    name_regex: Optional[builtins.str] = None,
                    output_file: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetV3TriggersResult:
    """
    This data source provides Fcv3 Trigger available to the user.[What is Trigger](https://next.api.alibabacloud.com/document/FC/2023-03-30/CreateTrigger)

    > **NOTE:** Available since v1.250.0.

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-exampleTriggerResourceAPI"
    function_name = config.get("functionName")
    if function_name is None:
        function_name = "terraform-exampleTriggerResourceAPI"
    trigger_name = config.get("triggerName")
    if trigger_name is None:
        trigger_name = "exampleTrigger_HTTP"
    function = alicloud.fc.V3Function("function",
        memory_size=512,
        cpu=0.5,
        handler="index.Handler",
        code={
            "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
        },
        function_name=name,
        runtime="python3.9",
        disk_size=512,
        log_config={
            "log_begin_rule": "None",
        })
    default_v3_trigger = alicloud.fc.V3Trigger("default",
        function_name=function.function_name,
        trigger_type="http",
        trigger_name="tf-exampleacceu-central-1fcv3trigger28547",
        description="create",
        qualifier="LATEST",
        trigger_config=json.dumps({
            "authType": "anonymous",
            "methods": [
                "GET",
                "POST",
            ],
        }))
    default = alicloud.fc.get_v3_triggers_output(ids=[default_v3_trigger.id],
        name_regex=default_v3_trigger.trigger_name,
        function_name=function_name)
    pulumi.export("alicloudFcv3TriggerExampleId", default.triggers[0].id)
    ```


    :param builtins.str function_name: Function Name
    :param Sequence[builtins.str] ids: A list of Trigger IDs. The value is formulated as `<function_name>:<trigger_name>`.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['functionName'] = function_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:fc/getV3Triggers:getV3Triggers', __args__, opts=opts, typ=GetV3TriggersResult).value

    return AwaitableGetV3TriggersResult(
        function_name=pulumi.get(__ret__, 'function_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        triggers=pulumi.get(__ret__, 'triggers'))
def get_v3_triggers_output(function_name: Optional[pulumi.Input[builtins.str]] = None,
                           ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                           name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                           output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetV3TriggersResult]:
    """
    This data source provides Fcv3 Trigger available to the user.[What is Trigger](https://next.api.alibabacloud.com/document/FC/2023-03-30/CreateTrigger)

    > **NOTE:** Available since v1.250.0.

    ## Example Usage

    ```python
    import pulumi
    import json
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-exampleTriggerResourceAPI"
    function_name = config.get("functionName")
    if function_name is None:
        function_name = "terraform-exampleTriggerResourceAPI"
    trigger_name = config.get("triggerName")
    if trigger_name is None:
        trigger_name = "exampleTrigger_HTTP"
    function = alicloud.fc.V3Function("function",
        memory_size=512,
        cpu=0.5,
        handler="index.Handler",
        code={
            "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
        },
        function_name=name,
        runtime="python3.9",
        disk_size=512,
        log_config={
            "log_begin_rule": "None",
        })
    default_v3_trigger = alicloud.fc.V3Trigger("default",
        function_name=function.function_name,
        trigger_type="http",
        trigger_name="tf-exampleacceu-central-1fcv3trigger28547",
        description="create",
        qualifier="LATEST",
        trigger_config=json.dumps({
            "authType": "anonymous",
            "methods": [
                "GET",
                "POST",
            ],
        }))
    default = alicloud.fc.get_v3_triggers_output(ids=[default_v3_trigger.id],
        name_regex=default_v3_trigger.trigger_name,
        function_name=function_name)
    pulumi.export("alicloudFcv3TriggerExampleId", default.triggers[0].id)
    ```


    :param builtins.str function_name: Function Name
    :param Sequence[builtins.str] ids: A list of Trigger IDs. The value is formulated as `<function_name>:<trigger_name>`.
    :param builtins.str name_regex: A regex string to filter results by Group Metric Rule name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['functionName'] = function_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:fc/getV3Triggers:getV3Triggers', __args__, opts=opts, typ=GetV3TriggersResult)
    return __ret__.apply(lambda __response__: GetV3TriggersResult(
        function_name=pulumi.get(__response__, 'function_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        triggers=pulumi.get(__response__, 'triggers')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpamIpamPoolAllocationArgs', 'IpamIpamPoolAllocation']

@pulumi.input_type
class IpamIpamPoolAllocationArgs:
    def __init__(__self__, *,
                 ipam_pool_id: pulumi.Input[builtins.str],
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 cidr_mask: Optional[pulumi.Input[builtins.int]] = None,
                 ipam_pool_allocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_allocation_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a IpamIpamPoolAllocation resource.
        :param pulumi.Input[builtins.str] ipam_pool_id: The ID of the IPAM Pool.
        :param pulumi.Input[builtins.str] cidr: The allocated address segment.
        :param pulumi.Input[builtins.int] cidr_mask: Create a custom reserved network segment from The IPAM address pool by entering a mask.
               
               > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_description: The description of the ipam pool alloctaion.
               It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_name: The name of the ipam pool allocation.
               It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        """
        pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if cidr_mask is not None:
            pulumi.set(__self__, "cidr_mask", cidr_mask)
        if ipam_pool_allocation_description is not None:
            pulumi.set(__self__, "ipam_pool_allocation_description", ipam_pool_allocation_description)
        if ipam_pool_allocation_name is not None:
            pulumi.set(__self__, "ipam_pool_allocation_name", ipam_pool_allocation_name)

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the IPAM Pool.
        """
        return pulumi.get(self, "ipam_pool_id")

    @ipam_pool_id.setter
    def ipam_pool_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ipam_pool_id", value)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The allocated address segment.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="cidrMask")
    def cidr_mask(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Create a custom reserved network segment from The IPAM address pool by entering a mask.

        > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        """
        return pulumi.get(self, "cidr_mask")

    @cidr_mask.setter
    def cidr_mask(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cidr_mask", value)

    @property
    @pulumi.getter(name="ipamPoolAllocationDescription")
    def ipam_pool_allocation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the ipam pool alloctaion.
        It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        """
        return pulumi.get(self, "ipam_pool_allocation_description")

    @ipam_pool_allocation_description.setter
    def ipam_pool_allocation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_pool_allocation_description", value)

    @property
    @pulumi.getter(name="ipamPoolAllocationName")
    def ipam_pool_allocation_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the ipam pool allocation.
        It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "ipam_pool_allocation_name")

    @ipam_pool_allocation_name.setter
    def ipam_pool_allocation_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_pool_allocation_name", value)


@pulumi.input_type
class _IpamIpamPoolAllocationState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 cidr_mask: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_allocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_allocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpamIpamPoolAllocation resources.
        :param pulumi.Input[builtins.str] cidr: The allocated address segment.
        :param pulumi.Input[builtins.int] cidr_mask: Create a custom reserved network segment from The IPAM address pool by entering a mask.
               
               > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        :param pulumi.Input[builtins.str] create_time: Instance creation time.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_description: The description of the ipam pool alloctaion.
               It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_name: The name of the ipam pool allocation.
               It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[builtins.str] ipam_pool_id: The ID of the IPAM Pool.
        :param pulumi.Input[builtins.str] region_id: When the IPAM Pool to which CIDR is allocated has the region attribute, this attribute is the IPAM Pool region.
               When the IPAM Pool to which CIDR is allocated does not have the region attribute, this attribute is the IPAM region.
        :param pulumi.Input[builtins.str] status: The status of the instance. Value:
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if cidr_mask is not None:
            pulumi.set(__self__, "cidr_mask", cidr_mask)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if ipam_pool_allocation_description is not None:
            pulumi.set(__self__, "ipam_pool_allocation_description", ipam_pool_allocation_description)
        if ipam_pool_allocation_name is not None:
            pulumi.set(__self__, "ipam_pool_allocation_name", ipam_pool_allocation_name)
        if ipam_pool_id is not None:
            pulumi.set(__self__, "ipam_pool_id", ipam_pool_id)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The allocated address segment.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter(name="cidrMask")
    def cidr_mask(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Create a custom reserved network segment from The IPAM address pool by entering a mask.

        > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        """
        return pulumi.get(self, "cidr_mask")

    @cidr_mask.setter
    def cidr_mask(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cidr_mask", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="ipamPoolAllocationDescription")
    def ipam_pool_allocation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the ipam pool alloctaion.
        It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        """
        return pulumi.get(self, "ipam_pool_allocation_description")

    @ipam_pool_allocation_description.setter
    def ipam_pool_allocation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_pool_allocation_description", value)

    @property
    @pulumi.getter(name="ipamPoolAllocationName")
    def ipam_pool_allocation_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the ipam pool allocation.
        It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "ipam_pool_allocation_name")

    @ipam_pool_allocation_name.setter
    def ipam_pool_allocation_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_pool_allocation_name", value)

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the IPAM Pool.
        """
        return pulumi.get(self, "ipam_pool_id")

    @ipam_pool_id.setter
    def ipam_pool_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipam_pool_id", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When the IPAM Pool to which CIDR is allocated has the region attribute, this attribute is the IPAM Pool region.
        When the IPAM Pool to which CIDR is allocated does not have the region attribute, this attribute is the IPAM region.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the instance. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:vpc/ipamIpamPoolAllocation:IpamIpamPoolAllocation")
class IpamIpamPoolAllocation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 cidr_mask: Optional[pulumi.Input[builtins.int]] = None,
                 ipam_pool_allocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_allocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Vpc Ipam Ipam Pool Allocation resource.

        Allocates or reserves a CIDR from an IPAM address pool.

        For information about Vpc Ipam Ipam Pool Allocation and how to use it, see [What is Ipam Pool Allocation](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamPoolAllocation).

        > **NOTE:** Available since v1.238.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
        default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
            ipam_scope_id=default_ipam.private_default_scope_id,
            pool_region_id="cn-hangzhou")
        default_ipam_pool_cidr = alicloud.vpc.IpamIpamPoolCidr("defaultIpamPoolCidr",
            cidr="10.0.0.0/8",
            ipam_pool_id=default_ipam_pool.id)
        default = alicloud.vpc.IpamIpamPoolAllocation("default",
            ipam_pool_allocation_description="init alloc desc",
            ipam_pool_allocation_name=name,
            cidr="10.0.0.0/20",
            ipam_pool_id=default_ipam_pool_cidr.ipam_pool_id)
        ```

        ## Import

        Vpc Ipam Ipam Pool Allocation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamPoolAllocation:IpamIpamPoolAllocation example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr: The allocated address segment.
        :param pulumi.Input[builtins.int] cidr_mask: Create a custom reserved network segment from The IPAM address pool by entering a mask.
               
               > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_description: The description of the ipam pool alloctaion.
               It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_name: The name of the ipam pool allocation.
               It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[builtins.str] ipam_pool_id: The ID of the IPAM Pool.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpamIpamPoolAllocationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Vpc Ipam Ipam Pool Allocation resource.

        Allocates or reserves a CIDR from an IPAM address pool.

        For information about Vpc Ipam Ipam Pool Allocation and how to use it, see [What is Ipam Pool Allocation](https://next.api.alibabacloud.com/document/VpcIpam/2023-02-28/CreateIpamPoolAllocation).

        > **NOTE:** Available since v1.238.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default_ipam = alicloud.vpc.IpamIpam("defaultIpam", operating_region_lists=["cn-hangzhou"])
        default_ipam_pool = alicloud.vpc.IpamIpamPool("defaultIpamPool",
            ipam_scope_id=default_ipam.private_default_scope_id,
            pool_region_id="cn-hangzhou")
        default_ipam_pool_cidr = alicloud.vpc.IpamIpamPoolCidr("defaultIpamPoolCidr",
            cidr="10.0.0.0/8",
            ipam_pool_id=default_ipam_pool.id)
        default = alicloud.vpc.IpamIpamPoolAllocation("default",
            ipam_pool_allocation_description="init alloc desc",
            ipam_pool_allocation_name=name,
            cidr="10.0.0.0/20",
            ipam_pool_id=default_ipam_pool_cidr.ipam_pool_id)
        ```

        ## Import

        Vpc Ipam Ipam Pool Allocation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/ipamIpamPoolAllocation:IpamIpamPoolAllocation example <id>
        ```

        :param str resource_name: The name of the resource.
        :param IpamIpamPoolAllocationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpamIpamPoolAllocationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 cidr_mask: Optional[pulumi.Input[builtins.int]] = None,
                 ipam_pool_allocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_allocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 ipam_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpamIpamPoolAllocationArgs.__new__(IpamIpamPoolAllocationArgs)

            __props__.__dict__["cidr"] = cidr
            __props__.__dict__["cidr_mask"] = cidr_mask
            __props__.__dict__["ipam_pool_allocation_description"] = ipam_pool_allocation_description
            __props__.__dict__["ipam_pool_allocation_name"] = ipam_pool_allocation_name
            if ipam_pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'ipam_pool_id'")
            __props__.__dict__["ipam_pool_id"] = ipam_pool_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
        super(IpamIpamPoolAllocation, __self__).__init__(
            'alicloud:vpc/ipamIpamPoolAllocation:IpamIpamPoolAllocation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[builtins.str]] = None,
            cidr_mask: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            ipam_pool_allocation_description: Optional[pulumi.Input[builtins.str]] = None,
            ipam_pool_allocation_name: Optional[pulumi.Input[builtins.str]] = None,
            ipam_pool_id: Optional[pulumi.Input[builtins.str]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'IpamIpamPoolAllocation':
        """
        Get an existing IpamIpamPoolAllocation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr: The allocated address segment.
        :param pulumi.Input[builtins.int] cidr_mask: Create a custom reserved network segment from The IPAM address pool by entering a mask.
               
               > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        :param pulumi.Input[builtins.str] create_time: Instance creation time.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_description: The description of the ipam pool alloctaion.
               It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        :param pulumi.Input[builtins.str] ipam_pool_allocation_name: The name of the ipam pool allocation.
               It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[builtins.str] ipam_pool_id: The ID of the IPAM Pool.
        :param pulumi.Input[builtins.str] region_id: When the IPAM Pool to which CIDR is allocated has the region attribute, this attribute is the IPAM Pool region.
               When the IPAM Pool to which CIDR is allocated does not have the region attribute, this attribute is the IPAM region.
        :param pulumi.Input[builtins.str] status: The status of the instance. Value:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpamIpamPoolAllocationState.__new__(_IpamIpamPoolAllocationState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["cidr_mask"] = cidr_mask
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["ipam_pool_allocation_description"] = ipam_pool_allocation_description
        __props__.__dict__["ipam_pool_allocation_name"] = ipam_pool_allocation_name
        __props__.__dict__["ipam_pool_id"] = ipam_pool_id
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["status"] = status
        return IpamIpamPoolAllocation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[builtins.str]:
        """
        The allocated address segment.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter(name="cidrMask")
    def cidr_mask(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Create a custom reserved network segment from The IPAM address pool by entering a mask.

        > **NOTE:**  Enter at least one of `Cidr` or **CidrMask.
        """
        return pulumi.get(self, "cidr_mask")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        Instance creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="ipamPoolAllocationDescription")
    def ipam_pool_allocation_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the ipam pool alloctaion.
        It must be 1 to 256 characters in length and must start with an English letter or Chinese character, but cannot start with 'http:// 'or 'https. If it is not filled in, it is empty. The default value is empty.
        """
        return pulumi.get(self, "ipam_pool_allocation_description")

    @property
    @pulumi.getter(name="ipamPoolAllocationName")
    def ipam_pool_allocation_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the ipam pool allocation.
        It must be 1 to 128 characters in length and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "ipam_pool_allocation_name")

    @property
    @pulumi.getter(name="ipamPoolId")
    def ipam_pool_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the IPAM Pool.
        """
        return pulumi.get(self, "ipam_pool_id")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        When the IPAM Pool to which CIDR is allocated has the region attribute, this attribute is the IPAM Pool region.
        When the IPAM Pool to which CIDR is allocated does not have the region attribute, this attribute is the IPAM region.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the instance. Value:
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PublicEndpointArgs', 'PublicEndpoint']

@pulumi.input_type
class PublicEndpointArgs:
    def __init__(__self__, *,
                 connection_string_prefix: pulumi.Input[builtins.str],
                 db_instance_id: pulumi.Input[builtins.str],
                 net_type: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a PublicEndpoint resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The public network connection string prefix of the instance.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] net_type: Network type of the connection address. Valid values:
               - Public: Public network.
        """
        pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "net_type", net_type)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Input[builtins.str]:
        """
        The public network connection string prefix of the instance.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> pulumi.Input[builtins.str]:
        """
        Network type of the connection address. Valid values:
        - Public: Public network.
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "net_type", value)


@pulumi.input_type
class _PublicEndpointState:
    def __init__(__self__, *,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 net_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PublicEndpoint resources.
        :param pulumi.Input[builtins.str] connection_string_prefix: The public network connection string prefix of the instance.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] net_type: Network type of the connection address. Valid values:
               - Public: Public network.
        """
        if connection_string_prefix is not None:
            pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if net_type is not None:
            pulumi.set(__self__, "net_type", net_type)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The public network connection string prefix of the instance.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Network type of the connection address. Valid values:
        - Public: Public network.
        """
        return pulumi.get(self, "net_type")

    @net_type.setter
    def net_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "net_type", value)


@pulumi.type_token("alicloud:clickhouseenterprisedbcluster/publicEndpoint:PublicEndpoint")
class PublicEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 net_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Click House Enterprise Db Cluster Public Endpoint resource.

        ClickHouse enterprise instance public network endpoint.

        For information about Click House Enterprise Db Cluster Public Endpoint and how to use it, see [What is Enterprise Db Cluster Public Endpoint](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateEndpoint).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        defaultaqnt22 = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("defaultaqnt22",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id)
        default = alicloud.clickhouseenterprisedbcluster.PublicEndpoint("default",
            db_instance_id=defaultaqnt22.id,
            net_type="Public",
            connection_string_prefix=defaultaqnt22.id)
        ```

        ## Import

        Click House Enterprise Db Cluster Public Endpoint can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/publicEndpoint:PublicEndpoint example <db_instance_id>:<net_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The public network connection string prefix of the instance.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] net_type: Network type of the connection address. Valid values:
               - Public: Public network.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PublicEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Click House Enterprise Db Cluster Public Endpoint resource.

        ClickHouse enterprise instance public network endpoint.

        For information about Click House Enterprise Db Cluster Public Endpoint and how to use it, see [What is Enterprise Db Cluster Public Endpoint](https://next.api.alibabacloud.com/document/clickhouse/2023-05-22/CreateEndpoint).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        region_id = config.get("regionId")
        if region_id is None:
            region_id = "cn-beijing"
        vsw_ip_range_i = config.get("vswIpRangeI")
        if vsw_ip_range_i is None:
            vsw_ip_range_i = "172.16.1.0/24"
        vpc_ip_range = config.get("vpcIpRange")
        if vpc_ip_range is None:
            vpc_ip_range = "172.16.0.0/12"
        zone_id_i = config.get("zoneIdI")
        if zone_id_i is None:
            zone_id_i = "cn-beijing-i"
        defaultkt_k_lu_m = alicloud.vpc.Network("defaultktKLuM", cidr_block=vpc_ip_range)
        default_tqwn3k = alicloud.vpc.Switch("defaultTQWN3k",
            vpc_id=defaultkt_k_lu_m.id,
            zone_id=zone_id_i,
            cidr_block=vsw_ip_range_i)
        defaultaqnt22 = alicloud.clickhouseenterprisedbcluster.ClickHouseEnterpriseDbCluster("defaultaqnt22",
            zone_id=zone_id_i,
            vpc_id=defaultkt_k_lu_m.id,
            scale_min="8",
            scale_max="16",
            vswitch_id=default_tqwn3k.id)
        default = alicloud.clickhouseenterprisedbcluster.PublicEndpoint("default",
            db_instance_id=defaultaqnt22.id,
            net_type="Public",
            connection_string_prefix=defaultaqnt22.id)
        ```

        ## Import

        Click House Enterprise Db Cluster Public Endpoint can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:clickhouseenterprisedbcluster/publicEndpoint:PublicEndpoint example <db_instance_id>:<net_type>
        ```

        :param str resource_name: The name of the resource.
        :param PublicEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PublicEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 net_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PublicEndpointArgs.__new__(PublicEndpointArgs)

            if connection_string_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'connection_string_prefix'")
            __props__.__dict__["connection_string_prefix"] = connection_string_prefix
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            if net_type is None and not opts.urn:
                raise TypeError("Missing required property 'net_type'")
            __props__.__dict__["net_type"] = net_type
        super(PublicEndpoint, __self__).__init__(
            'alicloud:clickhouseenterprisedbcluster/publicEndpoint:PublicEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
            db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            net_type: Optional[pulumi.Input[builtins.str]] = None) -> 'PublicEndpoint':
        """
        Get an existing PublicEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The public network connection string prefix of the instance.
        :param pulumi.Input[builtins.str] db_instance_id: The cluster ID.
        :param pulumi.Input[builtins.str] net_type: Network type of the connection address. Valid values:
               - Public: Public network.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PublicEndpointState.__new__(_PublicEndpointState)

        __props__.__dict__["connection_string_prefix"] = connection_string_prefix
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["net_type"] = net_type
        return PublicEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Output[builtins.str]:
        """
        The public network connection string prefix of the instance.
        """
        return pulumi.get(self, "connection_string_prefix")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        The cluster ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> pulumi.Output[builtins.str]:
        """
        Network type of the connection address. Valid values:
        - Public: Public network.
        """
        return pulumi.get(self, "net_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EtlArgs', 'Etl']

@pulumi.input_type
class EtlArgs:
    def __init__(__self__, *,
                 configuration: pulumi.Input['EtlConfigurationArgs'],
                 display_name: pulumi.Input[builtins.str],
                 job_name: pulumi.Input[builtins.str],
                 project: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Etl resource.
        :param pulumi.Input['EtlConfigurationArgs'] configuration: The ETL configuration. See `configuration` below.
        :param pulumi.Input[builtins.str] display_name: Data processing task display name.
        :param pulumi.Input[builtins.str] job_name: Unique identification of data processing task.
        :param pulumi.Input[builtins.str] project: Project Name.
        :param pulumi.Input[builtins.str] description: Data Processing Task Description.
        """
        pulumi.set(__self__, "configuration", configuration)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "job_name", job_name)
        pulumi.set(__self__, "project", project)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Input['EtlConfigurationArgs']:
        """
        The ETL configuration. See `configuration` below.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: pulumi.Input['EtlConfigurationArgs']):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[builtins.str]:
        """
        Data processing task display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Input[builtins.str]:
        """
        Unique identification of data processing task.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[builtins.str]:
        """
        Project Name.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Processing Task Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _EtlState:
    def __init__(__self__, *,
                 configuration: Optional[pulumi.Input['EtlConfigurationArgs']] = None,
                 create_time: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Etl resources.
        :param pulumi.Input['EtlConfigurationArgs'] configuration: The ETL configuration. See `configuration` below.
        :param pulumi.Input[builtins.int] create_time: The time when the data transformation job was created.
        :param pulumi.Input[builtins.str] description: Data Processing Task Description.
        :param pulumi.Input[builtins.str] display_name: Data processing task display name.
        :param pulumi.Input[builtins.str] job_name: Unique identification of data processing task.
        :param pulumi.Input[builtins.str] project: Project Name.
        :param pulumi.Input[builtins.str] status: The status of the data transformation job.
        """
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if job_name is not None:
            pulumi.set(__self__, "job_name", job_name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['EtlConfigurationArgs']]:
        """
        The ETL configuration. See `configuration` below.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['EtlConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The time when the data transformation job was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Processing Task Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data processing task display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique identification of data processing task.
        """
        return pulumi.get(self, "job_name")

    @job_name.setter
    def job_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "job_name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project Name.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the data transformation job.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:sls/etl:Etl")
class Etl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configuration: Optional[pulumi.Input[Union['EtlConfigurationArgs', 'EtlConfigurationArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Log Service (SLS) Etl resource.

        For information about Log Service (SLS) Etl and how to use it, see [What is Etl](https://next.api.alibabacloud.com/document/Sls/2020-12-30/CreateETL).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaulthh_a_po6 = alicloud.log.Project("defaulthhAPo6",
            description="terraform-etl-example-813",
            project_name="terraform-etl-example-330")
        defaultz_wk_lkp = alicloud.log.Store("defaultzWKLkp",
            hot_ttl=8,
            retention_period=30,
            shard_count=2,
            project_name=defaulthh_a_po6.id,
            logstore_name="example")
        default = alicloud.sls.Etl("default",
            project=defaulthh_a_po6.id,
            description="etl-1740472705-185721",
            configuration={
                "script": "* | extend a=1",
                "lang": "SPL",
                "role_arn": name,
                "sinks": [{
                    "name": "11111",
                    "endpoint": "cn-hangzhou-intranet.log.aliyuncs.com",
                    "project": "gy-hangzhou-huolang-1",
                    "logstore": "gy-rm2",
                    "datasets": ["__UNNAMED__"],
                    "role_arn": name,
                }],
                "logstore": defaultz_wk_lkp.logstore_name,
                "from_time": 1706771697,
                "to_time": 1738394097,
            },
            job_name="etl-1740472705-185721",
            display_name="etl-1740472705-185721")
        ```

        ## Import

        Log Service (SLS) Etl can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/etl:Etl example <project>:<job_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['EtlConfigurationArgs', 'EtlConfigurationArgsDict']] configuration: The ETL configuration. See `configuration` below.
        :param pulumi.Input[builtins.str] description: Data Processing Task Description.
        :param pulumi.Input[builtins.str] display_name: Data processing task display name.
        :param pulumi.Input[builtins.str] job_name: Unique identification of data processing task.
        :param pulumi.Input[builtins.str] project: Project Name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EtlArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Log Service (SLS) Etl resource.

        For information about Log Service (SLS) Etl and how to use it, see [What is Etl](https://next.api.alibabacloud.com/document/Sls/2020-12-30/CreateETL).

        > **NOTE:** Available since v1.248.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaulthh_a_po6 = alicloud.log.Project("defaulthhAPo6",
            description="terraform-etl-example-813",
            project_name="terraform-etl-example-330")
        defaultz_wk_lkp = alicloud.log.Store("defaultzWKLkp",
            hot_ttl=8,
            retention_period=30,
            shard_count=2,
            project_name=defaulthh_a_po6.id,
            logstore_name="example")
        default = alicloud.sls.Etl("default",
            project=defaulthh_a_po6.id,
            description="etl-1740472705-185721",
            configuration={
                "script": "* | extend a=1",
                "lang": "SPL",
                "role_arn": name,
                "sinks": [{
                    "name": "11111",
                    "endpoint": "cn-hangzhou-intranet.log.aliyuncs.com",
                    "project": "gy-hangzhou-huolang-1",
                    "logstore": "gy-rm2",
                    "datasets": ["__UNNAMED__"],
                    "role_arn": name,
                }],
                "logstore": defaultz_wk_lkp.logstore_name,
                "from_time": 1706771697,
                "to_time": 1738394097,
            },
            job_name="etl-1740472705-185721",
            display_name="etl-1740472705-185721")
        ```

        ## Import

        Log Service (SLS) Etl can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/etl:Etl example <project>:<job_name>
        ```

        :param str resource_name: The name of the resource.
        :param EtlArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EtlArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configuration: Optional[pulumi.Input[Union['EtlConfigurationArgs', 'EtlConfigurationArgsDict']]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 job_name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EtlArgs.__new__(EtlArgs)

            if configuration is None and not opts.urn:
                raise TypeError("Missing required property 'configuration'")
            __props__.__dict__["configuration"] = configuration
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if job_name is None and not opts.urn:
                raise TypeError("Missing required property 'job_name'")
            __props__.__dict__["job_name"] = job_name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Etl, __self__).__init__(
            'alicloud:sls/etl:Etl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            configuration: Optional[pulumi.Input[Union['EtlConfigurationArgs', 'EtlConfigurationArgsDict']]] = None,
            create_time: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            job_name: Optional[pulumi.Input[builtins.str]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'Etl':
        """
        Get an existing Etl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['EtlConfigurationArgs', 'EtlConfigurationArgsDict']] configuration: The ETL configuration. See `configuration` below.
        :param pulumi.Input[builtins.int] create_time: The time when the data transformation job was created.
        :param pulumi.Input[builtins.str] description: Data Processing Task Description.
        :param pulumi.Input[builtins.str] display_name: Data processing task display name.
        :param pulumi.Input[builtins.str] job_name: Unique identification of data processing task.
        :param pulumi.Input[builtins.str] project: Project Name.
        :param pulumi.Input[builtins.str] status: The status of the data transformation job.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EtlState.__new__(_EtlState)

        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["job_name"] = job_name
        __props__.__dict__["project"] = project
        __props__.__dict__["status"] = status
        return Etl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Output['outputs.EtlConfiguration']:
        """
        The ETL configuration. See `configuration` below.
        """
        return pulumi.get(self, "configuration")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.int]:
        """
        The time when the data transformation job was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Data Processing Task Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Data processing task display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="jobName")
    def job_name(self) -> pulumi.Output[builtins.str]:
        """
        Unique identification of data processing task.
        """
        return pulumi.get(self, "job_name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        Project Name.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the data transformation job.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ResourceArgs', 'Resource']

@pulumi.input_type
class ResourceArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 cluster_name: pulumi.Input[builtins.str],
                 machine_types: pulumi.Input['ResourceMachineTypesArgs'],
                 user_access_param: pulumi.Input['ResourceUserAccessParamArgs'],
                 cluster_desc: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Resource resource.
        :param pulumi.Input[builtins.str] cluster_id: Used to uniquely identify a computing cluster.
        :param pulumi.Input[builtins.str] cluster_name: Represents the name of the compute cluster, usually including the model number.
        :param pulumi.Input['ResourceMachineTypesArgs'] machine_types: Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        :param pulumi.Input['ResourceUserAccessParamArgs'] user_access_param: Used to define the access parameters for the user. See `user_access_param` below.
        :param pulumi.Input[builtins.str] cluster_desc: Used to provide a description or comment on the compute cluster.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "machine_types", machine_types)
        pulumi.set(__self__, "user_access_param", user_access_param)
        if cluster_desc is not None:
            pulumi.set(__self__, "cluster_desc", cluster_desc)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Used to uniquely identify a computing cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[builtins.str]:
        """
        Represents the name of the compute cluster, usually including the model number.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="machineTypes")
    def machine_types(self) -> pulumi.Input['ResourceMachineTypesArgs']:
        """
        Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        """
        return pulumi.get(self, "machine_types")

    @machine_types.setter
    def machine_types(self, value: pulumi.Input['ResourceMachineTypesArgs']):
        pulumi.set(self, "machine_types", value)

    @property
    @pulumi.getter(name="userAccessParam")
    def user_access_param(self) -> pulumi.Input['ResourceUserAccessParamArgs']:
        """
        Used to define the access parameters for the user. See `user_access_param` below.
        """
        return pulumi.get(self, "user_access_param")

    @user_access_param.setter
    def user_access_param(self, value: pulumi.Input['ResourceUserAccessParamArgs']):
        pulumi.set(self, "user_access_param", value)

    @property
    @pulumi.getter(name="clusterDesc")
    def cluster_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Used to provide a description or comment on the compute cluster.
        """
        return pulumi.get(self, "cluster_desc")

    @cluster_desc.setter
    def cluster_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_desc", value)


@pulumi.input_type
class _ResourceState:
    def __init__(__self__, *,
                 cluster_desc: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 machine_types: Optional[pulumi.Input['ResourceMachineTypesArgs']] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 user_access_param: Optional[pulumi.Input['ResourceUserAccessParamArgs']] = None):
        """
        Input properties used for looking up and filtering Resource resources.
        :param pulumi.Input[builtins.str] cluster_desc: Used to provide a description or comment on the compute cluster.
        :param pulumi.Input[builtins.str] cluster_id: Used to uniquely identify a computing cluster.
        :param pulumi.Input[builtins.str] cluster_name: Represents the name of the compute cluster, usually including the model number.
        :param pulumi.Input['ResourceMachineTypesArgs'] machine_types: Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        :param pulumi.Input[builtins.str] resource_id: The ID of the Resource.
        :param pulumi.Input['ResourceUserAccessParamArgs'] user_access_param: Used to define the access parameters for the user. See `user_access_param` below.
        """
        if cluster_desc is not None:
            pulumi.set(__self__, "cluster_desc", cluster_desc)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if machine_types is not None:
            pulumi.set(__self__, "machine_types", machine_types)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if user_access_param is not None:
            pulumi.set(__self__, "user_access_param", user_access_param)

    @property
    @pulumi.getter(name="clusterDesc")
    def cluster_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Used to provide a description or comment on the compute cluster.
        """
        return pulumi.get(self, "cluster_desc")

    @cluster_desc.setter
    def cluster_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_desc", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Used to uniquely identify a computing cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Represents the name of the compute cluster, usually including the model number.
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="machineTypes")
    def machine_types(self) -> Optional[pulumi.Input['ResourceMachineTypesArgs']]:
        """
        Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        """
        return pulumi.get(self, "machine_types")

    @machine_types.setter
    def machine_types(self, value: Optional[pulumi.Input['ResourceMachineTypesArgs']]):
        pulumi.set(self, "machine_types", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Resource.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="userAccessParam")
    def user_access_param(self) -> Optional[pulumi.Input['ResourceUserAccessParamArgs']]:
        """
        Used to define the access parameters for the user. See `user_access_param` below.
        """
        return pulumi.get(self, "user_access_param")

    @user_access_param.setter
    def user_access_param(self, value: Optional[pulumi.Input['ResourceUserAccessParamArgs']]):
        pulumi.set(self, "user_access_param", value)


@pulumi.type_token("alicloud:eflo/resource:Resource")
class Resource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_desc: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 machine_types: Optional[pulumi.Input[Union['ResourceMachineTypesArgs', 'ResourceMachineTypesArgsDict']]] = None,
                 user_access_param: Optional[pulumi.Input[Union['ResourceUserAccessParamArgs', 'ResourceUserAccessParamArgsDict']]] = None,
                 __props__=None):
        """
        ## Import

        Eflo Resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/resource:Resource example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_desc: Used to provide a description or comment on the compute cluster.
        :param pulumi.Input[builtins.str] cluster_id: Used to uniquely identify a computing cluster.
        :param pulumi.Input[builtins.str] cluster_name: Represents the name of the compute cluster, usually including the model number.
        :param pulumi.Input[Union['ResourceMachineTypesArgs', 'ResourceMachineTypesArgsDict']] machine_types: Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        :param pulumi.Input[Union['ResourceUserAccessParamArgs', 'ResourceUserAccessParamArgsDict']] user_access_param: Used to define the access parameters for the user. See `user_access_param` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Eflo Resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eflo/resource:Resource example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ResourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_desc: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_name: Optional[pulumi.Input[builtins.str]] = None,
                 machine_types: Optional[pulumi.Input[Union['ResourceMachineTypesArgs', 'ResourceMachineTypesArgsDict']]] = None,
                 user_access_param: Optional[pulumi.Input[Union['ResourceUserAccessParamArgs', 'ResourceUserAccessParamArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceArgs.__new__(ResourceArgs)

            __props__.__dict__["cluster_desc"] = cluster_desc
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            if machine_types is None and not opts.urn:
                raise TypeError("Missing required property 'machine_types'")
            __props__.__dict__["machine_types"] = machine_types
            if user_access_param is None and not opts.urn:
                raise TypeError("Missing required property 'user_access_param'")
            __props__.__dict__["user_access_param"] = user_access_param
            __props__.__dict__["resource_id"] = None
        super(Resource, __self__).__init__(
            'alicloud:eflo/resource:Resource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_desc: Optional[pulumi.Input[builtins.str]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            cluster_name: Optional[pulumi.Input[builtins.str]] = None,
            machine_types: Optional[pulumi.Input[Union['ResourceMachineTypesArgs', 'ResourceMachineTypesArgsDict']]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None,
            user_access_param: Optional[pulumi.Input[Union['ResourceUserAccessParamArgs', 'ResourceUserAccessParamArgsDict']]] = None) -> 'Resource':
        """
        Get an existing Resource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_desc: Used to provide a description or comment on the compute cluster.
        :param pulumi.Input[builtins.str] cluster_id: Used to uniquely identify a computing cluster.
        :param pulumi.Input[builtins.str] cluster_name: Represents the name of the compute cluster, usually including the model number.
        :param pulumi.Input[Union['ResourceMachineTypesArgs', 'ResourceMachineTypesArgsDict']] machine_types: Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        :param pulumi.Input[builtins.str] resource_id: The ID of the Resource.
        :param pulumi.Input[Union['ResourceUserAccessParamArgs', 'ResourceUserAccessParamArgsDict']] user_access_param: Used to define the access parameters for the user. See `user_access_param` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceState.__new__(_ResourceState)

        __props__.__dict__["cluster_desc"] = cluster_desc
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["machine_types"] = machine_types
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["user_access_param"] = user_access_param
        return Resource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterDesc")
    def cluster_desc(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Used to provide a description or comment on the compute cluster.
        """
        return pulumi.get(self, "cluster_desc")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Used to uniquely identify a computing cluster.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[builtins.str]:
        """
        Represents the name of the compute cluster, usually including the model number.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="machineTypes")
    def machine_types(self) -> pulumi.Output['outputs.ResourceMachineTypes']:
        """
        Generally refers to the type or instance type of a computing resource. See `machine_types` below.
        """
        return pulumi.get(self, "machine_types")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Resource.
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="userAccessParam")
    def user_access_param(self) -> pulumi.Output['outputs.ResourceUserAccessParam']:
        """
        Used to define the access parameters for the user. See `user_access_param` below.
        """
        return pulumi.get(self, "user_access_param")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetScalingRulesResult',
    'AwaitableGetScalingRulesResult',
    'get_scaling_rules',
    'get_scaling_rules_output',
]

@pulumi.output_type
class GetScalingRulesResult:
    """
    A collection of values returned by getScalingRules.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, rules=None, scaling_group_id=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if scaling_group_id and not isinstance(scaling_group_id, str):
            raise TypeError("Expected argument 'scaling_group_id' to be a str")
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of scaling rule ids.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of scaling rule names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetScalingRulesRuleResult']:
        """
        A list of scaling rules. Each element contains the following attributes:
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[builtins.str]:
        """
        ID of the scaling group.
        """
        return pulumi.get(self, "scaling_group_id")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        Type of the scaling rule.
        """
        return pulumi.get(self, "type")


class AwaitableGetScalingRulesResult(GetScalingRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScalingRulesResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            rules=self.rules,
            scaling_group_id=self.scaling_group_id,
            type=self.type)


def get_scaling_rules(ids: Optional[Sequence[builtins.str]] = None,
                      name_regex: Optional[builtins.str] = None,
                      output_file: Optional[builtins.str] = None,
                      scaling_group_id: Optional[builtins.str] = None,
                      type: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScalingRulesResult:
    """
    This data source provides available scaling rule resources.

    > **NOTE:** Available since v1.39.0

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-ex"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    my_name = f"{name}-{default_integer['result']}"
    default = alicloud.get_zones(available_disk_category="cloud_efficiency",
        available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default",
        vpc_name=my_name,
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=default.zones[0].id,
        vswitch_name=my_name)
    default_scaling_group = alicloud.ess.ScalingGroup("default",
        min_size=1,
        max_size=1,
        scaling_group_name=my_name,
        removal_policies=[
            "OldestInstance",
            "NewestInstance",
        ],
        vswitch_ids=[default_switch.id])
    default_scaling_rule = alicloud.ess.ScalingRule("default",
        scaling_group_id=default_scaling_group.id,
        scaling_rule_name=my_name,
        adjustment_type="PercentChangeInCapacity",
        adjustment_value=1)
    scalingrules_ds = alicloud.ess.get_scaling_rules_output(scaling_group_id=default_scaling_group.id,
        ids=[default_scaling_rule.id],
        name_regex=my_name)
    pulumi.export("firstScalingRule", scalingrules_ds.rules[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of scaling rule IDs.
    :param builtins.str name_regex: A regex string to filter resulting scaling rules by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str scaling_group_id: Scaling group id the scaling rules belong to.
    :param builtins.str type: Type of scaling rule.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['scalingGroupId'] = scaling_group_id
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ess/getScalingRules:getScalingRules', __args__, opts=opts, typ=GetScalingRulesResult).value

    return AwaitableGetScalingRulesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        rules=pulumi.get(__ret__, 'rules'),
        scaling_group_id=pulumi.get(__ret__, 'scaling_group_id'),
        type=pulumi.get(__ret__, 'type'))
def get_scaling_rules_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                             name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             scaling_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetScalingRulesResult]:
    """
    This data source provides available scaling rule resources.

    > **NOTE:** Available since v1.39.0

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-ex"
    default_integer = random.index.Integer("default",
        min=10000,
        max=99999)
    my_name = f"{name}-{default_integer['result']}"
    default = alicloud.get_zones(available_disk_category="cloud_efficiency",
        available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default",
        vpc_name=my_name,
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=default.zones[0].id,
        vswitch_name=my_name)
    default_scaling_group = alicloud.ess.ScalingGroup("default",
        min_size=1,
        max_size=1,
        scaling_group_name=my_name,
        removal_policies=[
            "OldestInstance",
            "NewestInstance",
        ],
        vswitch_ids=[default_switch.id])
    default_scaling_rule = alicloud.ess.ScalingRule("default",
        scaling_group_id=default_scaling_group.id,
        scaling_rule_name=my_name,
        adjustment_type="PercentChangeInCapacity",
        adjustment_value=1)
    scalingrules_ds = alicloud.ess.get_scaling_rules_output(scaling_group_id=default_scaling_group.id,
        ids=[default_scaling_rule.id],
        name_regex=my_name)
    pulumi.export("firstScalingRule", scalingrules_ds.rules[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of scaling rule IDs.
    :param builtins.str name_regex: A regex string to filter resulting scaling rules by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str scaling_group_id: Scaling group id the scaling rules belong to.
    :param builtins.str type: Type of scaling rule.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['scalingGroupId'] = scaling_group_id
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ess/getScalingRules:getScalingRules', __args__, opts=opts, typ=GetScalingRulesResult)
    return __ret__.apply(lambda __response__: GetScalingRulesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        rules=pulumi.get(__response__, 'rules'),
        scaling_group_id=pulumi.get(__response__, 'scaling_group_id'),
        type=pulumi.get(__response__, 'type')))
